# Horus Media Server Client

An [Horus Media Server](https://horus.nu/horus-geo-suite/) client python library

## [Install latest release](https://github.com/horus-view-and-explore/horus-media-client/wiki/Install-latest-release)


## Example tools

Interactive examples

### Recordings tool
This example can be used to list published recordings.
```
python -m horus_media_examples.recordings_tool --help
```

### Export spherical
This example can be used to export spherical views from a set of recordings.
```
python -m horus_media_examples.export_spherical --help
```
### Export orthographic
This example can be used to export orthographic views from a set of recordings.
```
python -m horus_media_examples.export_orthographic --help
```

## [Run the example strategy](https://github.com/horus-view-and-explore/horus-media-client/wiki/Example-strategy-tool)

```
python3 -m horus_media_examples.example_strategy --help
```
